# eeg_positions data

Here you find standard EEG electrode coordinates in several formats.

- all files are in tab-separated-value (TSV) format
- There are two subfolders, corresponding to the electrodes that lie on the equator of the sphere
    - `Fpz-T8-Oz-T7` and `Nz-T10-Iz-T9`
    - see the general documentation for more information
- Each of the subfolders contains the coordinate files
    - in 2D
    - in 3D
    - for different "systems" (10-20, 10-10, 10-05)
- All files contain the anatomical landmarks: nasion (NAS), left- and right preauricular point (LPA, RPA)


If you have no idea which file you need, getting the `Nz-T10-Iz-T9/standard_1005_3D.tsv` file (or corresponding `2D`) is probably best.
